[PEP651 stub package for rdkit](https://peps.python.org/pep-0561/#stub-only-packages)

These stubs were generated using [mypy stubgen](https://mypy.readthedocs.io/en/stable/stubgen.html)
and edited extensively to cleanup the parts that were most broken.

The stubs are partially complete but there is more work to be done to remove the references
to `Any`. Contributions are welcome.

This package currently targets rdkit version `2022.03.3`.

## Use

To use these stubs, add the `rdkit-stubs` package to your python environment.

```
pip install rdkit-stubs
```

## Developing

To test your contributions to these stubs you can import the local package from another one of your
projects. First clone the repo then `pip install -e <path-to-this-repo>`.

## License

Licensed under either of

 * Apache License, Version 2.0
   ([LICENSE-APACHE](LICENSE-APACHE) or http://www.apache.org/licenses/LICENSE-2.0)
 * MIT license
   ([LICENSE-MIT](LICENSE-MIT) or http://opensource.org/licenses/MIT)

at your option.

## Contribution

Unless you explicitly state otherwise, any contribution intentionally submitted
for inclusion in the work by you, as defined in the Apache-2.0 license, shall be
dual licensed as above, without any additional terms or conditions.
